@@ -407,6 +407,7 @@ class ServiceControlManager:
 
     @contextmanager
     def get_handle(self):
+        # some various combinations of permissions that I've found work to get a handle
         permission_combos = (
             (win32service.SC_MANAGER_ALL_ACCESS, win32service.SERVICE_ALL_ACCESS),
             (win32service.SC_MANAGER_CONNECT, win32service.SERVICE_CHANGE_CONFIG),
@@ -418,7 +419,9 @@ class ServiceControlManager:
         try:
             for idx, values in enumerate(permission_combos):
                 sc_perm, svc_perm = values
-                logging.debug("getting service handle")
+                logging.debug(
+                    "attempting to get service handle for %s", self.service_name
+                )
                 svc_ctrl_manager = win32service.OpenSCManager(None, None, sc_perm)
                 logging.debug("opening service")
 
@@ -427,7 +430,6 @@ class ServiceControlManager:
                         svc_ctrl_manager, self.service_name, svc_perm
                     )
 
-                    logging.debug("yielding service handle")
                 except pywintypes.error as e:
                     if idx == len(permission_combos) - 1:
                         raise
@@ -436,6 +438,8 @@ class ServiceControlManager:
                         continue
 
                 if hs:
+                    logging.debug("got service handle for %s", self.service_name)
+
                     yield hs
                     break
         finally:
@@ -448,33 +452,58 @@ class ServiceControlManager:
 
 
 @contextmanager
-def stop_and_disable(service_name: str, disregard_already_stopped: bool = True) -> None:
+def stopped_service(
+    service_name: str,
+    ignore_stopped: bool = True,
+    wait_for: int = 10,
+    also_disable: bool = True,
+) -> None:
+    """
+    Context manager to stop a service and then start it again.
+
+    :param service_name: The name of the service to stop and start
+    :param ignore_stopped: If True, don't raise if the service is already stopped. Default: True.
+    :param wait_for: How long to wait for each of these actions: stop, disable, enable,
+        start. Defaults to 10 seconds.
+    :param also_disable: If True, disable the service after stopping it. Default: True.
+    """
     service = ServiceControlManager(service_name)
+
+    # stop the service
     previous_state = service.status.state.value
 
     try:
-        service.status.state.stop()
+        service.status.state.stop(wait_for_seconds=wait_for)
     except pywintypes.error as e:
-        if (
-            e.winerror == winerror.ERROR_SERVICE_NOT_ACTIVE
-            and disregard_already_stopped
-        ):
+        if e.winerror == winerror.ERROR_SERVICE_NOT_ACTIVE and ignore_stopped:
+            # service is already stopped and we don't care
             pass
         else:
+            # service is already stopped or some other error
             raise
 
+    # disable the service
     previous_start_type = service.config.start_type.value
-    service.config.start_type.set_disabled()
 
+    if also_disable:
+        service.config.start_type.set_disabled(wait_for_seconds=wait_for)
+
+    # yield the service
     yield service
 
-    service.config.start_type.set_start_type(previous_start_type)
+    # enable the service
+    if also_disable:
+        service.config.start_type.set_start_type(
+            previous_start_type, wait_for_seconds=wait_for
+        )
+
+    # start the service
     if previous_state in (
         win32service.SERVICE_RUNNING,
         win32service.SERVICE_START_PENDING,
         win32service.SERVICE_CONTINUE_PENDING,
     ):
-        service.status.state.start()
+        service.status.state.start(wait_for_seconds=wait_for)
 
 
 def is_admin():
@@ -557,38 +586,6 @@ def stop_service(service_name: str) -> None:
     win32serviceutil.StopService(service_name)
 
 
-def disable_service(service_name: str) -> None:
-    """
-    Disables a service.
-
-    :param service_name: Name of the service to disable.
-    :return: None
-    """
-    win32serviceutil.ChangeServiceConfig(
-        None,
-        service_name,
-        startType=win32service.SERVICE_DISABLED,
-    )
-    logging.debug("waiting for service to be disabled")
-    wait_for_service_config_status(service_name, win32service.SERVICE_DISABLED, 10)
-
-
-def enable_service(service_name: str) -> None:
-    """
-    Enables a service.
-
-    :param service_name: Name of the service to enable.
-    :return: None
-    """
-    win32serviceutil.ChangeServiceConfig(
-        None,
-        service_name,
-        startType=win32service.SERVICE_AUTO_START,
-    )
-    start = time.time()
-    wait_for_service_config_status(service_name, win32service.SERVICE_AUTO_START, 10)
-
-
 def wait_for_service_config_status(
     service_name: str, status: int, wait_seconds: int
 ) -> None:
